<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Redo</name>
    <message>
        <location filename="../RedoInit.js" line="+2"/>
        <source>&amp;Redo</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Przywróć</translatorcomment>
        <translation>&amp;Ponów</translation>
    </message>
</context>
</TS>
